# eloy

Image Processing for Astronomy

---

A simple Python package containing functions to process astronomical images. This package aims at being simple and relies on a minimal number of dependencies. The development philosophy of this package is to stick as much as possible to the functional programming paradigm by avoiding the definition of object classes.


## License
Copyright (c) 2021-2024 Lionel Garcia, Inc.

`eloy` is free software made available under the MIT License. For details
see the `LICENSE` file.
